=========
Changelog
=========

Version 0.2.2
=============
 - Raise exception when an authentication failure occurs

Version 0.2.1
=============
 - Raise exception when unable to parse data from initial connection

Version 0.1.1
=============
 - Add additional logging during authentication for troubleshooting

Version 0.1
===========

- Initial implementation
